@@ -1,6 +1,7 @@
 #helper function for word.associate, termco_d and termco(not exported)
 term.find <-
-function(str, mat, logic = FALSE, unlist = FALSE){
+function(str, mat, logic = FALSE, unlist = FALSE, apostrophe.remove = FALSE, 
+    char.keep = "~~", digit.remove = FALSE, ...){
     tester <- function(x, y, logic){
         p <- suppressWarnings(unlist(grepl(x, y, fixed = TRUE)))
         if (!logic) {
@@ -11,8 +12,9 @@ function(str, mat, logic = FALSE, unlist = FALSE){
     spacer <- function(string){
         sapply(string, function(x) paste0(" ", x, " "), 
             USE.NAMES = FALSE)
-      }
-    str <- spacer(strip(str, lower.case = FALSE))
+    }
+    str <- spacer(strip(str, lower.case = FALSE, char.keep = char.keep, 
+        apostrophe.remove = apostrophe.remove, digit.remove = digit.remove, ...))
     findit1 <- function(x, logic = TRUE) {
         sapply(x, function(z) tester(z, str, logic))
     }
